@@ -100,10 +100,10 @@ typedef struct _WacomDeviceDatabase WacomDeviceDatabase;
  */
 enum WacomErrorCode {
 	WERROR_NONE,		/**< No error has occured */
-	WERROR_BAD_ALLOC,		/**< Allocation error */
+	WERROR_BAD_ALLOC,	/**< Allocation error */
 	WERROR_INVALID_PATH,	/**< A path specified is invalid */
-	WERROR_INVALID_DB,		/**< The passed DB is invalid */
-	WERROR_BAD_ACCESS,		/**< Invalid permissions to access the path */
+	WERROR_INVALID_DB,	/**< The passed DB is invalid */
+	WERROR_BAD_ACCESS,	/**< Invalid permissions to access the path */
 	WERROR_UNKNOWN_MODEL,	/**< Unsupported/unknown device */
 };
 
@@ -111,10 +111,10 @@ enum WacomErrorCode {
  * Bus types for tablets.
  */
 typedef enum {
-	WBUSTYPE_UNKNOWN,		/**< Unknown/unsupported bus type */
+	WBUSTYPE_UNKNOWN,	/**< Unknown/unsupported bus type */
 	WBUSTYPE_USB,		/**< USB tablet */
-	WBUSTYPE_SERIAL,		/**< Serial tablet */
-	WBUSTYPE_BLUETOOTH,		/**< Bluetooth tablet */
+	WBUSTYPE_SERIAL,	/**< Serial tablet */
+	WBUSTYPE_BLUETOOTH,	/**< Bluetooth tablet */
 	WBUSTYPE_I2C,		/**< I2C tablet */
 } WacomBusType;
 
@@ -386,6 +386,22 @@ const char* libwacom_get_match(const WacomDevice *device);
  */
 const WacomMatch** libwacom_get_matches(const WacomDevice *device);
 
+/**
+ * Return the match string of the paired device for this device. A paired
+ * device is a device with a different match string but that shares the
+ * physical device with this device.
+ *
+ * If the return value is NULL, no device is paired with this device or all
+ * paired devices have the same WacomMatch as this device.
+ *
+ * The returned device may not be a libwacom device itself.
+ *
+ * @param device The tablet to query
+ * @return A pointer to paired device for this device. Do not
+ * modify this pointer or any content!
+ */
+const WacomMatch* libwacom_get_paired_device(const WacomDevice *device);
+
 /**
  * @param device The tablet to query
  * @return The numeric product ID for this device
